@@ -90,7 +90,19 @@ def uniform_validator(validator, variables_mapping: VariablesMapping = None,
         expect_value = validator["expect"]
         message = validator.get("message", "")
         comparator = validator.get("comparator", "eq")
-
+    elif "t1" in validator and "t2" in validator:
+        check_item = validator["t1"]
+        expect_value = validator["t2"]
+        message = validator.get("message", "")
+        comparator = "diff"
+        kwargs = validator.get("kwargs", "")
+        return {
+            "check": check_item,
+            "expect": expect_value,
+            "assert": comparator,
+            "kwargs": kwargs,
+            "message": message,
+        }
     elif len(validator) == 1:
         # format2
         comparator = list(validator.keys())[0]
@@ -170,6 +182,7 @@ class ResponseObject(object):
             "cookies": self.cookies,
             "body": self.body,
         }
+        if expr is None: return None
         try:
             key_list = [key for key in resp_obj_meta.keys()]
             flag = False
@@ -196,7 +209,7 @@ class ResponseObject(object):
 
         extract_mapping = {}
         for key, field in extractors.items():
-            field_value = self._search_jmespath(field)
+            field_value = self._search_jmespath(parse_data(field, variables_mapping, functions_mapping))
             if field_value == field:  # if not jmespath syntax
                 field_value = parse_data(field, variables_mapping, functions_mapping)
                 variables_mapping[key] = field_value
@@ -274,7 +287,10 @@ class ResponseObject(object):
                 }
 
                 try:
-                    assert_func(check_value, expect_value, message)
+                    if assert_method == "diff":
+                        assert_func(check_value, expect_value, u_validator["kwargs"])
+                    else:
+                        assert_func(check_value, expect_value, )
                     validate_msg += "\t==> pass"
                     logger.info(validate_msg)
                     validator_dict["check_result"] = "pass"
